==> openjdk-17_17.0.11~7ea.orig.tar.xz: openjdk-17-17.0.11~7ea/test/hotspot/jtreg/compiler/lib/ir_framework/driver/irmatching/parser/AbstractLine.java <==
/*
 * Copyright (c) 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package compiler.lib.ir_framework.driver.irmatching.parser;

import java.io.BufferedReader;
import java.io.IOException;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * Base class of a read line from the hotspot_pid* file.
 */
abstract class AbstractLine {
    private final BufferedReader reader;
    protected String line;
    private final Pattern compileIdPatternForTestClass;

    public AbstractLine(BufferedReader reader, Pattern compileIdPatternForTestClass) {
        this.reader = reader;
        this.compileIdPatternForTestClass = compileIdPatternForTestClass;
    }

    public String getLine() {
        return line;
    }

    /**
     * Read next line and return it. If we've reached the end of the file, return NULL instead.
     */
    public boolean readLine() throws IOException {
        line = reader.readLine();
        return line != null;
    }

    /**
     * Is this line a start of a method in the test class? We only care about test class entries. There might be non-class
     * entries as well if the user specified additional compile commands. Ignore these.
     */
    public boolean isTestClassCompilation() {
        if (isCompilation()) {
            Matcher matcher = compileIdPatternForTestClass.matcher(line);
            return matcher.find();
        }
        return false;
    }

    /**
     * Is this header a C2 non-OSR compilation header entry?
     */
    public boolean isCompilation() {
        return line.startsWith("<task_queued") && notOSRCompilation() && notC2Compilation();
    }

    /**
     * OSR compilations have compile_kind set.
     */
    protected boolean notOSRCompilation() {
        return !line.contains("compile_kind='");
    }

    /**
     * Non-C2 compilations have level set.
     */
    private boolean notC2Compilation() {
        return !line.contains("level='");
    }
}

==> openjdk-19_19~20ea.orig.tar.xz: openjdk-19-19~20ea/test/hotspot/jtreg/compiler/lib/ir_framework/driver/irmatching/parser/AbstractLine.java <==
/*
 * Copyright (c) 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package compiler.lib.ir_framework.driver.irmatching.parser;

import java.io.BufferedReader;
import java.io.IOException;

/**
 * Base class of a read line from the hotspot_pid* file.
 */
abstract class AbstractLine {
    private final BufferedReader reader;
    protected String line;

    public AbstractLine(BufferedReader reader) {
        this.reader = reader;
    }

    public String getLine() {
        return line;
    }

    /**
     * Read next line and return it. If we've reached the end of the file, return NULL instead.
     */
    public boolean readLine() throws IOException {
        line = reader.readLine();
        return line != null;
    }
}
